doc

package
v0.9.7 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 27, 2021 License: MIT Imports: 7 Imported by: 0

Documentation

Index

Constants

const FileName = "package_dependencies.md"

FileName is the name of the documentation file (package_dependencies.md).

Variables

This section is empty.

Functions

func GenerateTable

func GenerateTable(
	idx int,
	links data.PatternList,
	docFiles []string,
	depMap data.DependencyMap,
	rootPkg string,
) string

GenerateTable generates the dependency matrix for the idx package(s) from links.

func RelPath

func RelPath(basepath, targetpath string) string

RelPath calculates the relative path from 'basepath' to 'targetpath'. This is very similar to filepath.Rel() but not OS specific but it is working by purely lexical processing like the path package.

func WriteDocs

func WriteDocs(
	dtPkgs []string,
	depMap data.DependencyMap,
	linkDocPkgs map[string]struct{},
	rootPkg, root string,
)

WriteDocs generates documentation for the packages 'dtPkgs' and writes it to files. If linkDocPkgs is filled it will be used to link to packages instead of reporting all the details in one table.

Types

This section is empty.

Jump to